Metabolic reprogramming Knowledgebase
=====================================

.. image:: https://img.shields.io/pypi/v/metabolike
    :alt: PyPI Release
    :target: https://pypi.org/project/metabolike/
.. image:: https://img.shields.io/github/workflow/status/y1zhou/metabolike/Release%20to%20PyPI
    :alt: Release Build Status
    :target: https://github.com/y1zhou/metabolike/actions/workflows/release.yml
.. image:: https://img.shields.io/github/workflow/status/y1zhou/metabolike/PyTest?label=test
    :alt: PyTest Workflow Status
    :target: https://github.com/y1zhou/metabolike/actions/workflows/pytest.yml

A Python package that aggregates the data from BRENDA_ and BioCyc_ into one unified `graph database`_.
The MetaCyc (BioCyc) database is imported to a graph database using the provided SBML file and various ``.dat`` files.

.. _BRENDA: https://brenda-enzymes.org/
.. _BioCyc: https://biocyc.org/
.. _graph database: https://neo4j.com/

To-Do
-----

* Add tutorial for the package
* Add documentation to the CLI
* Add Dockerfile and docker-compose file
* Add tests
